@@ -1,7 +1,8 @@
 # coding=utf-8
 from __future__ import print_function
 import argparse
-import urllib3
+from urllib3.exceptions import InsecureRequestWarning
+import warnings
 import logging
 import os
 from ibm_ai_openscale_cli.enums import ResetType, MLEngineType
@@ -197,7 +198,8 @@ def initialize(args):
         _validate_db_provided(args.postgres, args.icd, args.db2)
         args.is_icp = True
         logger.log_info('SSL verification is not used for requests against ICP Environment, disabling "InsecureRequestWarning"')
-        urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
+        with warnings.catch_warnings():
+            warnings.simplefilter('ignore', InsecureRequestWarning)
     if args.history_only and (not args.deployment_name or not args.extend):
         log_error_raise_exception('ERROR: --history-only requires that both --extend and --deployment-name also be specified')
     if args.values_per_score > 1 and not args.ml_engine_type == MLEngineType.WML:
