@@ -4,14 +4,13 @@ import datetime
 import random
 import json
 import pandas as pd
-import pickle
 from ibm_ai_openscale_cli.enums import MLEngineType
 from io import StringIO
 from ibm_ai_openscale_cli.utility_classes.fastpath_logger import FastpathLogger
 from ibm_ai_openscale.supporting_classes import BluemixCloudObjectStorageReference
 from ibm_ai_openscale.supporting_classes import PayloadRecord
 from ibm_ai_openscale.supporting_classes import MeasurementRecord
-from ibm_ai_openscale_cli.utility_classes.utils import jsonFileToDict
+from ibm_ai_openscale_cli.utility_classes.utils import jsonFileToDict, get_path, load_pickle_file
 from ibm_ai_openscale_cli.database_classes.cos import CloudObjectStorage
 from pathlib import Path
 from ibm_ai_openscale_cli.utility_classes.keras_unstructured_binary_text import read_lines, split_lines, format_scoring_input
@@ -53,14 +52,15 @@ class Model:
         if model_instances > 1:
             self.name += str(model_instances)
 
+        cwd = os.path.dirname(__file__)
         if self._args.custom_model_directory:
             self._model_dir = self._args.custom_model_directory
         elif self._args.mrm and 'PreProd' in self.name:
-            self._model_dir = os.path.join(os.path.dirname(__file__), name.split('PreProd')[0])
+            self._model_dir = get_path(cwd, [cwd, name.split('PreProd')[0]])
         elif self._args.mrm and 'Challenger' in self.name:
-            self._model_dir = os.path.join(os.path.dirname(__file__), name.split('Challenger')[0])
+            self._model_dir = get_path(cwd, [cwd, name.split('Challenger')[0]])
         else:
-            self._model_dir = os.path.join(os.path.dirname(__file__), name)
+            self._model_dir = get_path(cwd, [cwd, name])
 
         env_name = '' if self._args.env_dict['name'] == 'YPPROD' else self._args.env_dict['name']
 
@@ -132,8 +132,8 @@ class Model:
         elif self.training_data_csv_file:
             if self.configuration_data['asset_metadata']['input_data_type'] == 'UNSTRUCTURED_TEXT':
                 self.is_unstructured_text = True
-                with open(self._get_file_path(Model.TOKENIZER_PICKLE_FILENAME), 'rb') as handle:
-                    self.tokenizer = pickle.load(handle)
+                pickle_file_path = self._get_file_path(Model.TOKENIZER_PICKLE_FILENAME)
+                self.tokenizer = load_pickle_file(pickle_file_path)
                 data, labels = split_lines(read_lines(self.training_data_csv_file))
                 self.training_data = [data, labels]
             elif self.configuration_data['asset_metadata']['input_data_type'] == 'UNSTRUCTURED_IMAGE':
@@ -217,24 +217,24 @@ class Model:
         Eg. /path/to/sagemaker/training_data_statistics.json OR /path/to/training_data_statistics.json OR None
         """
         if self._args.mrm and 'Challenger' in self.name:
-            engine_specific_path = os.path.join(self._model_dir, self._args.ml_engine_type.name.lower(), 'mrm', filename)
+            engine_specific_path = get_path(self._model_dir, [self._model_dir, self._args.ml_engine_type.name.lower(), 'mrm', filename])
             if Path(engine_specific_path).is_file():
                 return engine_specific_path
             else:
                 return None
 
-        engine_specific_path = os.path.join(self._model_dir, self._args.ml_engine_type.name.lower())
+        engine_specific_path = get_path(self._model_dir, [self._model_dir, self._args.ml_engine_type.name.lower()])
         if self._args.ml_engine_type is MLEngineType.WML:
             api_version = 'v4' if self._args.v4 else 'v3'
-            engine_specific_path = os.path.join(engine_specific_path, api_version, filename)
+            engine_specific_path = get_path(engine_specific_path, [engine_specific_path, api_version, filename])
         if Path(engine_specific_path).is_file():
             return engine_specific_path
         else:
-            engine_specific_path = os.path.join(self._model_dir, self._args.ml_engine_type.name.lower(), filename)
+            engine_specific_path = get_path(self._model_dir, [self._model_dir, self._args.ml_engine_type.name.lower(), filename])
         if Path(engine_specific_path).is_file():
             return engine_specific_path
         else:
-            path = os.path.join(self._model_dir, filename)
+            path = get_path(self._model_dir, [self._model_dir, filename])
             if Path(path).is_file():
                 return path
         return None
